SourceRole

Enum SourceRole 

#[non_exhaustive]
pub enum SourceRole { Primary, EnclosingConstruct, MacroExpansion, ResourceRequest, Package, FontDefinition, Resource, }
How a source range contributed to a node.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Primary

The primary user visible expression source.



EnclosingConstruct

Enclosing construct or macro invocation range; entries are emitted innermost first.



MacroExpansion

Macro expansion whose expansion produced this node.



ResourceRequest

User source declaration that requested a resource, such as \input or \usepackage.



Package

Package file that defined a macro or environment used here.



FontDefinition

TeX font definition source such as .fd.



Resource

Generic resource file referenced during typesetting.