pub struct BoxMetrics {
pub width: Length,
pub height: Length,
pub depth: Length,
pub shift: Length,
}Expand description
TeX box dimensions.
Fields
width: LengthHorizontal extent.
height: LengthHeight above baseline.
depth: LengthDepth below baseline.
shift: LengthShift applied when this box is placed in a parent list.
Implementations
Sourceimpl BoxMetrics
impl BoxMetrics
Sourcepub const fn baseline_offset(&self) -> Length
pub const fn baseline_offset(&self) -> Length
Baseline offset from the top edge of the box.
Sourcepub const fn total_height(&self) -> Length
pub const fn total_height(&self) -> Length
Height plus depth, giving the total vertical extent.