pub struct Drawing {
pub commands: Vec<DrawCommand>,
pub stroke: Option<Stroke>,
pub fill: Option<Color>,
}Expand description
Backend neutral drawing data using path commands.
Fields
commands: Vec<DrawCommand>Ordered path commands composing the drawing.
stroke: Option<Stroke>Stroke style, or None if the path is not stroked.
fill: Option<Color>Fill color, or None if the path is not filled.