pub struct LayoutBox {
pub kind: BoxKind,
pub metrics: BoxMetrics,
pub children: Vec<NodeId>,
}Expand description
TeX style box data retained in renderer neutral layout IR.
Fields
kind: BoxKindWhether this is a horizontal, vertical, math, or text box.
metrics: BoxMetricsTeX box metrics.
children: Vec<NodeId>Child nodes positioned relative to this box.