pub struct LayoutList {
pub kind: ListKind,
pub children: Vec<NodeId>,
}Expand description
TeX style list data retained before or after box packaging.
Fields
kind: ListKindWhether this is a horizontal, vertical, math, paragraph, or text list.
children: Vec<NodeId>Child node identifiers in list order.