LayoutNode

Struct LayoutNode 

pub struct LayoutNode {
    pub id: NodeId,
    pub origin: Point,
    pub width: Length,
    pub height: Length,
    pub depth: Length,
    pub primary_source: Option<SourceRange>,
    pub kind: LayoutNodeKind,
}
A node of the layout tree.

Fields

id: NodeId

Id, equal to the node’s index in Fragment::nodes.

origin: Point

Reference point relative to the parent’s reference point, the box’s left baseline point, y down.

width: Length

Horizontal extent to the right of the reference point.

height: Length

Extent above the reference point.

depth: Length

Extent below the reference point.

primary_source: Option<SourceRange>

The source span this node was typeset from.

kind: LayoutNodeKind

What the node is.

Implementations

Source

impl LayoutNode

pub fn children(&self) -> &[NodeId]

Returns the children of a box, empty for every other node.