pub struct Surface {
pub width: Length,
pub height: Length,
pub baseline: Length,
}Expand description
Extent of a fragment, the root box’s width, total height and height above the baseline.
Fields
width: LengthRoot width.
height: LengthRoot height plus depth.
baseline: LengthDistance from the top edge down to the baseline, the root height.
Implementations