#[non_exhaustive]pub enum FragmentError {
IdMismatch {
index: usize,
id: NodeId,
},
RootOutOfRange(NodeId),
RootNotAtOrigin,
SurfaceMismatch,
ChildOutOfRange {
parent: NodeId,
child: NodeId,
},
MultipleParents(NodeId),
Unreachable(NodeId),
SourceIdMismatch {
index: usize,
id: SourceId,
},
UnknownSource {
node: NodeId,
source: SourceId,
},
}Expand description
Why a fragment breaks the IR invariants.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IdMismatch
A node is stored at an index other than its id.
RootOutOfRange(NodeId)
The root id indexes no node.
RootNotAtOrigin
The root origin is not (0, 0).
SurfaceMismatch
The surface does not match the root’s width, height and depth.
ChildOutOfRange
A box lists a child id that indexes no node.
MultipleParents(NodeId)
A node is listed as a child more than once, or the root is listed as a child.
Unreachable(NodeId)
A node is not reachable from the root.
SourceIdMismatch
A source file is stored at an index other than its id.
UnknownSource
A node or entry refers to an unregistered source file.