#[non_exhaustive]pub enum LayoutNodeKind {
Box(LayoutBox),
List(LayoutList),
Group {
children: Vec<NodeId>,
},
GlyphRun(GlyphRun),
Rule(Rule),
Glue(Glue),
Kern(Kern),
Drawing(Drawing),
}Expand description
Renderer neutral node payloads.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Box(LayoutBox)
TeX style box with width, height, depth, and positioned children.
List(LayoutList)
TeX style list before or after packaging into a box.
Group
A grouping of child nodes with no layout box.
GlyphRun(GlyphRun)
A sequence of shaped glyphs from one font.
Rule(Rule)
A solid rule, such as a fraction bar.
Glue(Glue)
Flexible spacing emitted after layout resolution.
Kern(Kern)
Fixed horizontal or vertical spacing between adjacent items.
Drawing(Drawing)
Drawing commands for extensible delimiters or geometry beyond glyphs and rules.